@@ -13,7 +13,7 @@ use uuid::Uuid;
 pub struct Roast {
     pub id: String,
     pub bean_name: String,
-    pub starting_weight: i32,
+    pub starting_weight: u32,
     pub beans_in: NaiveDateTime,
     pub first_crack_start: NaiveDateTime,
     pub first_crack_finish: NaiveDateTime,
